@@ -2,10 +2,10 @@
 # SPDX-License-Identifier: MIT
 from time import sleep
 import board
-import busio
 from adafruit_ms8607 import MS8607
 
-i2c = busio.I2C(board.SCL, board.SDA)
+i2c = board.I2C()  # uses board.SCL and board.SDA
+# i2c = board.STEMMA_I2C()  # For using the built-in STEMMA QT connector on a microcontroller
 sensor = MS8607(i2c)
 
 while True:
